Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(401)

Unified Diff: third_party/WebKit/Source/core/html/HTMLEmbedElement.cpp

Issue 2737713002: Rename updateWidgets to updatePlugins (Closed)
Patch Set: Rename updateWidgets to updatePlugins Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/html/HTMLEmbedElement.cpp
diff --git a/third_party/WebKit/Source/core/html/HTMLEmbedElement.cpp b/third_party/WebKit/Source/core/html/HTMLEmbedElement.cpp
index da88411a5e0a4e25b7cd5ddc9f032c03289d5e9d..af9a5011818432cbbb6c160ae2c4f7a9c3be9748 100644
--- a/third_party/WebKit/Source/core/html/HTMLEmbedElement.cpp
+++ b/third_party/WebKit/Source/core/html/HTMLEmbedElement.cpp
@@ -100,7 +100,7 @@ void HTMLEmbedElement::parseAttribute(
if (pos != kNotFound)
m_serviceType = m_serviceType.left(pos);
if (layoutObject()) {
- setNeedsWidgetUpdate(true);
+ setNeedsPluginUpdate(true);
layoutObject()->setNeedsLayoutAndFullPaintInvalidation(
"Embed type changed");
} else {
@@ -119,7 +119,7 @@ void HTMLEmbedElement::parseAttribute(
} else if (layoutObject()) {
// Check if this Embed can transition from potentially-active to active
if (fastHasAttribute(typeAttr)) {
- setNeedsWidgetUpdate(true);
+ setNeedsPluginUpdate(true);
lazyReattachIfNeeded();
}
} else {
@@ -139,12 +139,12 @@ void HTMLEmbedElement::parametersForPlugin(Vector<String>& paramNames,
}
}
// FIXME: This should be unified with HTMLObjectElement::updateWidget and
// moved down into HTMLPluginElement.cpp
-void HTMLEmbedElement::updateWidgetInternal() {
+void HTMLEmbedElement::updatePluginInternal() {
DCHECK(!layoutEmbeddedItem().showsUnavailablePluginIndicator());
- DCHECK(needsWidgetUpdate());
- setNeedsWidgetUpdate(false);
+ DCHECK(needsPluginUpdate());
+ setNeedsPluginUpdate(false);
if (m_url.isEmpty() && m_serviceType.isEmpty())
return;
« no previous file with comments | « third_party/WebKit/Source/core/html/HTMLEmbedElement.h ('k') | third_party/WebKit/Source/core/html/HTMLEmbedElementTest.cpp » ('j') | no next file with comments »
@@ -139,12 +139,12 @@ void HTMLEmbedElement::parametersForPlugin(Vector<String>& paramNames,
}
}
-// FIXME: This should be unified with HTMLObjectElement::updateWidget and
+// FIXME: This should be unified with HTMLObjectElement::updatePlugin and
// moved down into HTMLPluginElement.cpp

Powered by Google App Engine
This is Rietveld 408576698